Change Log
##########

..
   All enhancements and patches to edx_recommendations will be documented
   in this file.  It adheres to the structure of https://keepachangelog.com/ ,
   but in reStructuredText instead of Markdown (for ease of incorporation into
   Sphinx documentation and the PyPI description).

   This project adheres to Semantic Versioning (https://semver.org/).

.. There should always be an "Unreleased" section for changes pending release.

Unreleased
**********
*

[1.0.6] - 2023-09-25
**********************************************
**What's Changed**
* Updated settings file and default values

[1.0.5] - 2023-09-25
**********************************************
**What's Changed**
* Fixed formatting for PyPI release

[1.0.4] - 2023-09-25
**********************************************
**What's Changed**
* Added PyPI publish workflow for the package

[1.0.3] - 2023-09-22
**********************************************
**What's Changed**
* Added Support for Django 4.2

[1.0.2] - 2023-08-25
**********************************************
**What's Changed**

* Added recommendations unavailable event for learner home amplitude recommendations
* Removed constraint for edx-drf-extensions

**Documentation Updates**

* Updated docstring for cross product recommendations api endpoint


[1.0.0] - 2023-08-09
**********************************************
**What's Changed**

* Moved existing recommendations APIs to this plugin
* Added tests for the APIs and utils

**Documentation Updates**

* Added purpose of this repo as an ADR
* Added pull request template and updated README file with initial setup guide

[0.1.0] – 2023-05-15
**********************************************

* First release on PyPI.
